# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.integration import open_a_i_integration_pb2 as qwak_dot_integration_dot_open__a__i__integration__pb2
from _qwak_proto.qwak.integration import opsgenie_integration_pb2 as qwak_dot_integration_dot_opsgenie__integration__pb2
from _qwak_proto.qwak.integration import pagerduty_integration_pb2 as qwak_dot_integration_dot_pagerduty__integration__pb2
from _qwak_proto.qwak.integration import slack_app_integration_pb2 as qwak_dot_integration_dot_slack__app__integration__pb2
from _qwak_proto.qwak.integration import hugging_face_integration_pb2 as qwak_dot_integration_dot_hugging__face__integration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/integration/integration.proto\x12\x1bqwak.integration.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+qwak/integration/open_a_i_integration.proto\x1a+qwak/integration/opsgenie_integration.proto\x1a,qwak/integration/pagerduty_integration.proto\x1a,qwak/integration/slack_app_integration.proto\x1a/qwak/integration/hugging_face_integration.proto\"\xac\x04\n\x0bIntegration\x12\x16\n\x0eintegration_id\x18\x01 \x01(\t\x12J\n\x11jfrog_integration\x18\x02 \x01(\x0b\x32-.qwak.integration.management.JFrogIntegrationH\x00\x12P\n\x14opsgenie_integration\x18\x03 \x01(\x0b\x32\x30.qwak.integration.management.OpsgenieIntegrationH\x00\x12R\n\x15pagerduty_integration\x18\x04 \x01(\x0b\x32\x31.qwak.integration.management.PagerdutyIntegrationH\x00\x12V\n\x1aqwak_slack_app_integration\x18\x05 \x01(\x0b\x32\x30.qwak.integration.management.SlackAppIntegrationH\x00\x12L\n\x12openai_integration\x18\x07 \x01(\x0b\x32..qwak.integration.management.OpenAIIntegrationH\x00\x12W\n\x18hugging_face_integration\x18\x08 \x01(\x0b\x32\x33.qwak.integration.management.HuggingFaceIntegrationH\x00\x12\x0c\n\x04name\x18\x06 \x01(\tB\x06\n\x04type\"\xce\x04\n\x0fIntegrationSpec\x12S\n\x16jfrog_integration_spec\x18\x01 \x01(\x0b\x32\x31.qwak.integration.management.JFrogIntegrationSpecH\x00\x12Y\n\x19opsgenie_integration_spec\x18\x02 \x01(\x0b\x32\x34.qwak.integration.management.OpsgenieIntegrationSpecH\x00\x12[\n\x1apagerduty_integration_spec\x18\x03 \x01(\x0b\x32\x35.qwak.integration.management.PagerdutyIntegrationSpecH\x00\x12_\n\x1fqwak_slack_app_integration_spec\x18\x04 \x01(\x0b\x32\x34.qwak.integration.management.SlackAppIntegrationSpecH\x00\x12U\n\x17openai_integration_spec\x18\x06 \x01(\x0b\x32\x32.qwak.integration.management.OpenAIIntegrationSpecH\x00\x12`\n\x1dhugging_face_integration_spec\x18\x07 \x01(\x0b\x32\x37.qwak.integration.management.HuggingFaceIntegrationSpecH\x00\x12\x0c\n\x04name\x18\x05 \x01(\tB\x06\n\x04spec\"V\n\x10JFrogIntegration\x12\x42\n\x0ejfrog_settings\x18\x01 \x01(\x0b\x32*.qwak.integration.management.JFrogSettings\"o\n\x14JFrogIntegrationSpec\x12\x13\n\x0b\x61\x64min_token\x18\x01 \x01(\t\x12\x42\n\x0ejfrog_settings\x18\x02 \x01(\x0b\x32*.qwak.integration.management.JFrogSettings\"\xb3\x01\n\rJFrogSettings\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x1b\n\x13python_repositories\x18\x02 \x03(\t\x12\x1e\n\x16huggingface_repository\x18\x03 \x01(\t\x12%\n\x1d\x61llow_additional_repositories\x18\x04 \x01(\x08\x12,\n$create_huggingface_remote_repository\x18\x05 \x01(\x08\"\xbe\x04\n\x19IntegrationValidationSpec\x12Q\n\x15jfrog_validation_spec\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.JFrogValidationSpecH\x00\x12W\n\x18opsgenie_validation_spec\x18\x02 \x01(\x0b\x32\x33.qwak.integration.management.OpsgenieValidationSpecH\x00\x12Y\n\x19pagerduty_validation_spec\x18\x03 \x01(\x0b\x32\x34.qwak.integration.management.PagerdutyValidationSpecH\x00\x12]\n\x1eqwak_slack_app_validation_spec\x18\x04 \x01(\x0b\x32\x33.qwak.integration.management.SlackAppValidationSpecH\x00\x12S\n\x16openai_validation_spec\x18\x05 \x01(\x0b\x32\x31.qwak.integration.management.OpenAIValidationSpecH\x00\x12^\n\x1chugging_face_validation_spec\x18\x06 \x01(\x0b\x32\x36.qwak.integration.management.HuggingFaceValidationSpecH\x00\x42\x06\n\x04type\"<\n\x13JFrogValidationSpec\x12\x13\n\x0b\x61\x64min_token\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\"\xe7\x04\n\x12IntegrationOptions\x12Y\n\x19jfrog_integration_options\x18\x01 \x01(\x0b\x32\x34.qwak.integration.management.JFrogIntegrationOptionsH\x00\x12_\n\x1copsgenie_integration_options\x18\x02 \x01(\x0b\x32\x37.qwak.integration.management.OpsgenieIntegrationOptionsH\x00\x12\x61\n\x1dpagerduty_integration_options\x18\x03 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyIntegrationOptionsH\x00\x12\x65\n\"qwak_slack_app_integration_options\x18\x04 \x01(\x0b\x32\x37.qwak.integration.management.SlackAppIntegrationOptionsH\x00\x12[\n\x1aopenai_integration_options\x18\x05 \x01(\x0b\x32\x35.qwak.integration.management.OpenAIIntegrationOptionsH\x00\x12\x66\n hugging_face_integration_options\x18\x06 \x01(\x0b\x32:.qwak.integration.management.HuggingFaceIntegrationOptionsH\x00\x42\x06\n\x04type\"\xd8\x01\n\x17JFrogIntegrationOptions\x12[\n%available_private_python_repositories\x18\x01 \x03(\x0b\x32,.qwak.integration.management.JfrogRepository\x12`\n*available_private_huggingface_repositories\x18\x02 \x03(\x0b\x32,.qwak.integration.management.JfrogRepository\"\x1f\n\x0fJfrogRepository\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x8d\x01\n\x1bValidationIntegrationResult\x12\x15\n\ris_successful\x18\x01 \x01(\x08\x12@\n\x07options\x18\x02 \x01(\x0b\x32/.qwak.integration.management.IntegrationOptions\x12\x15\n\rerror_message\x18\x03 \x01(\t*\xef\x01\n\x0fIntegrationType\x12\x1c\n\x18INTEGRATION_TYPE_INVALID\x10\x00\x12\x1a\n\x16INTEGRATION_TYPE_JFROG\x10\x01\x12\x1d\n\x19INTEGRATION_TYPE_OPSGENIE\x10\x02\x12\x1e\n\x1aINTEGRATION_TYPE_PAGERDUTY\x10\x03\x12#\n\x1fINTEGRATION_TYPE_QWAK_SLACK_APP\x10\x04\x12\x1b\n\x17INTEGRATION_TYPE_OPENAI\x10\x05\x12!\n\x1dINTEGRATION_TYPE_HUGGING_FACE\x10\x06\x42H\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _globals['_INTEGRATIONTYPE']._serialized_start=3520
  _globals['_INTEGRATIONTYPE']._serialized_end=3759
  _globals['_INTEGRATION']._serialized_start=332
  _globals['_INTEGRATION']._serialized_end=888
  _globals['_INTEGRATIONSPEC']._serialized_start=891
  _globals['_INTEGRATIONSPEC']._serialized_end=1481
  _globals['_JFROGINTEGRATION']._serialized_start=1483
  _globals['_JFROGINTEGRATION']._serialized_end=1569
  _globals['_JFROGINTEGRATIONSPEC']._serialized_start=1571
  _globals['_JFROGINTEGRATIONSPEC']._serialized_end=1682
  _globals['_JFROGSETTINGS']._serialized_start=1685
  _globals['_JFROGSETTINGS']._serialized_end=1864
  _globals['_INTEGRATIONVALIDATIONSPEC']._serialized_start=1867
  _globals['_INTEGRATIONVALIDATIONSPEC']._serialized_end=2441
  _globals['_JFROGVALIDATIONSPEC']._serialized_start=2443
  _globals['_JFROGVALIDATIONSPEC']._serialized_end=2503
  _globals['_INTEGRATIONOPTIONS']._serialized_start=2506
  _globals['_INTEGRATIONOPTIONS']._serialized_end=3121
  _globals['_JFROGINTEGRATIONOPTIONS']._serialized_start=3124
  _globals['_JFROGINTEGRATIONOPTIONS']._serialized_end=3340
  _globals['_JFROGREPOSITORY']._serialized_start=3342
  _globals['_JFROGREPOSITORY']._serialized_end=3373
  _globals['_VALIDATIONINTEGRATIONRESULT']._serialized_start=3376
  _globals['_VALIDATIONINTEGRATIONRESULT']._serialized_end=3517
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from pathlib import Path
from typing import TYPE_CHECKING, Optional, Tuple

from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSourceSpec as ProtoDataSourceSpec,
)
from _qwak_proto.qwak.feature_store.v1.internal.data_source.data_source_service_pb2 import (
    GetDataSourceSourceCodeUploadResponse,
)
from qwak.clients.feature_store import FeatureRegistryClient
from qwak.exceptions import QwakException
from qwak.feature_store._common.artifact_utils import ArtifactSpec, ArtifactsUploader
from qwak.feature_store._common.source_code_spec import SourceCodeSpec
from qwak.feature_store._common.source_code_spec_factory import SourceCodeSpecFactory
from qwak.feature_store.data_sources.attributes import DataSourceAttributes
from qwak.feature_store.validations.validation_options import (
    DataSourceValidationOptions,
)
from qwak.feature_store.validations.validation_response import SuccessValidationResponse

if TYPE_CHECKING:
    try:
        import pandas as pd
    except ImportError:
        pass


@dataclass
class BaseSource(ABC):
    name: str
    description: str
    attributes: DataSourceAttributes = field(
        init=False, default_factory=lambda: DataSourceAttributes()
    )

    @abstractmethod
    def _to_proto(self, artifact_url: Optional[str] = None) -> ProtoDataSourceSpec:
        """
        Internal qwak function, converts this BaseSource instance to its protobuf representation.
        Args:
            artifact_url: provided if this base source artifact has already been uploaded
            data_source_definition_path: path to the module instantiating this base source
        """
        pass

    def _get_artifacts(self) -> Optional["ArtifactSpec"]:
        return None

    def _upload_artifact(self) -> Optional[str]:
        artifact: Optional["ArtifactSpec"] = self._get_artifacts()
        if artifact:
            return ArtifactsUploader.upload(artifact)

    def _prepare_and_get(
        self,
        artifact_url: Optional[str] = None,
        source_definition_path: Optional[Path] = None,
    ) -> Tuple[ProtoDataSourceSpec, Optional[str]]:
        uploaded_artifact_url: Optional[str] = artifact_url

        if not artifact_url:
            uploaded_artifact_url = self._upload_artifact()

        if source_definition_path:
            code_upload_args: (
                GetDataSourceSourceCodeUploadResponse
            ) = FeatureRegistryClient().get_datasource_source_code_presign_url(
                ds_name=self.name, repository_name=getattr(self, "repository")
            )
            source_code_spec: SourceCodeSpec = (
                SourceCodeSpecFactory.get_zip_source_code_spec(
                    main_entity_path=source_definition_path,
                    url=code_upload_args.upload_url,
                    extra_headers=code_upload_args.extra_headers,
                )
            )

            self.attributes = DataSourceAttributes(source_code_spec=source_code_spec)

        proto_spec: ProtoDataSourceSpec = self._to_proto(
            artifact_url=uploaded_artifact_url
        )

        proto_spec.MergeFrom(
            ProtoDataSourceSpec(data_source_attributes=self.attributes._to_proto())
        )

        return proto_spec, uploaded_artifact_url

    @classmethod
    @abstractmethod
    def _from_proto(cls, proto):
        pass

    def get_sample(
        self,
        number_of_rows: int = 10,
        validation_options: Optional[DataSourceValidationOptions] = None,
    ) -> "pd.DataFrame":
        """
        Tries to get a sample of length `number_rows` from the data source.
        Args:
            number_of_rows: number of rows to get from data source
            validation_options: validation options
        Returns:
            A tuple containing the resulting dataframe and a tuple of the columns names and types.
            (the types are pyspark dataframe types)
        """
        from qwak.feature_store.validations.validator import FeaturesOperatorValidator

        v = FeaturesOperatorValidator()

        response, _ = v.validate_data_source(
            data_source=self,
            sample_size=number_of_rows,
            validation_options=validation_options,
            silence_specific_exceptions=False,
        )

        if isinstance(response, SuccessValidationResponse):
            return response.sample
        else:
            raise QwakException(f"Sampling failed: \n{response}")



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HuggingFaceIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGING_FACE_API_TOKEN_SYSTEM_SECRET_DESCRIPTOR_FIELD_NUMBER: builtins.int
    @property
    def hugging_face_api_token_system_secret_descriptor(self) -> global___HuggingFaceApiTokenSystemSecretDescriptor: ...
    def __init__(
        self,
        *,
        hugging_face_api_token_system_secret_descriptor: global___HuggingFaceApiTokenSystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_system_secret_descriptor", b"hugging_face_api_token_system_secret_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_system_secret_descriptor", b"hugging_face_api_token_system_secret_descriptor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["hugging_face_api_token_system_secret_descriptor"] | None: ...

global___HuggingFaceIntegration = HuggingFaceIntegration

class HuggingFaceIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGING_FACE_API_TOKEN_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def hugging_face_api_token_auth_config(self) -> global___HuggingFaceApiTokenAuthConfig: ...
    def __init__(
        self,
        *,
        hugging_face_api_token_auth_config: global___HuggingFaceApiTokenAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["hugging_face_api_token_auth_config"] | None: ...

global___HuggingFaceIntegrationSpec = HuggingFaceIntegrationSpec

class HuggingFaceValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGING_FACE_API_TOKEN_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def hugging_face_api_token_auth_config(self) -> global___HuggingFaceApiTokenAuthConfig: ...
    def __init__(
        self,
        *,
        hugging_face_api_token_auth_config: global___HuggingFaceApiTokenAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "hugging_face_api_token_auth_config", b"hugging_face_api_token_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["hugging_face_api_token_auth_config"] | None: ...

global___HuggingFaceValidationSpec = HuggingFaceValidationSpec

class HuggingFaceApiTokenAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_TOKEN_FIELD_NUMBER: builtins.int
    api_token: builtins.str
    def __init__(
        self,
        *,
        api_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token", b"api_token"]) -> None: ...

global___HuggingFaceApiTokenAuthConfig = HuggingFaceApiTokenAuthConfig

class HuggingFaceApiTokenSystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    API_TOKEN_SECRET_KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    api_token_secret_key: builtins.str
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        api_token_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token_secret_key", b"api_token_secret_key", "secret_name", b"secret_name"]) -> None: ...

global___HuggingFaceApiTokenSystemSecretDescriptor = HuggingFaceApiTokenSystemSecretDescriptor

class HuggingFaceIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HuggingFaceIntegrationOptions = HuggingFaceIntegrationOptions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.v0.environments.environment_pb2
import qwak.administration.v1.environments.environment_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    environment_name: builtins.str
    """Environment name"""
    cluster_id: builtins.str
    """The JFrogML Cluster the environment is deployed in."""
    @property
    def spec(self) -> qwak.administration.v1.environments.environment_pb2.EnvironmentRuntimeConfigSpec:
        """Environment configuration"""
    def __init__(
        self,
        *,
        environment_name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        spec: qwak.administration.v1.environments.environment_pb2.EnvironmentRuntimeConfigSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "environment_name", b"environment_name", "spec", b"spec"]) -> None: ...

global___CreateEnvironmentRequest = CreateEnvironmentRequest

class CreateEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Created environment"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___CreateEnvironmentResponse = CreateEnvironmentResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/jobs/v1/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.jobs.v1 import job_pb2 as qwak_dot_feature__store_dot_jobs_dot_v1_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/jobs/v1/job_service.proto\x12\x1aqwak.feature.store.jobs.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$qwak/feature_store/jobs/v1/job.proto\"b\n!DeleteFeaturesetJobByJobIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\"F\n\"DeleteFeaturesetJobByJobIdResponse\x12 \n\x18\x64\x65leted_job_record_count\x18\x01 \x01(\x05\"L\n\x0f\x41pplyJobRequest\x12\x39\n\njob_record\x18\x01 \x01(\x0b\x32%.qwak.feature.store.jobs.v1.JobRecord\":\n\x10\x41pplyJobResponse\x12\x16\n\x0ejob_running_id\x18\x01 \x01(\x03\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"F\n\x15InitPaginationRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"Q\n\x16InitPaginationResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12!\n\x19pagination_session_max_id\x18\x02 \x01(\x03\"\x8b\x01\n\x0fListJobsRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x13\n\x0bpage_number\x18\x04 \x01(\x05\x12!\n\x19pagination_session_max_id\x18\x05 \x01(\x03\"G\n\x10ListJobsResponse\x12\x33\n\x04jobs\x18\x01 \x03(\x0b\x32%.qwak.feature.store.jobs.v1.JobRecord\"N\n\x1dGetLatestSuccessfulJobRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"D\n\x13GetLatestJobRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"J\n\x14GetLatestJobResponse\x12\x32\n\x03job\x18\x01 \x01(\x0b\x32%.qwak.feature.store.jobs.v1.JobRecord\"c\n\x1eGetLatestSuccessfulJobResponse\x12\x32\n\x03job\x18\x01 \x01(\x0b\x32%.qwak.feature.store.jobs.v1.JobRecord\x12\r\n\x05\x66ound\x18\x02 \x01(\x08\"#\n!GetAllLatestSuccessfulJobsRequest\"Y\n\"GetAllLatestSuccessfulJobsResponse\x12\x33\n\x04jobs\x18\x01 \x03(\x0b\x32%.qwak.feature.store.jobs.v1.JobRecord\"L\n\x1b\x44\x65leteFeaturesetJobsRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"A\n\x1c\x44\x65leteFeaturesetJobsResponse\x12!\n\x19\x64\x65leted_job_records_count\x18\x01 \x01(\x05\"\x96\x01\n\x17GetJobsSummariesRequest\x12\x34\n\x10lower_time_bound\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x10upper_time_bound\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\r\n\x0bupper_bound\"j\n\x18GetJobsSummariesResponse\x12N\n\x0ejobs_summaries\x18\x01 \x03(\x0b\x32\x36.qwak.feature.store.jobs.v1.FeaturesetLevelJobsSummary2\x9f\t\n\nJobService\x12\x65\n\x08\x41pplyJob\x12+.qwak.feature.store.jobs.v1.ApplyJobRequest\x1a,.qwak.feature.store.jobs.v1.ApplyJobResponse\x12w\n\x0eInitPagination\x12\x31.qwak.feature.store.jobs.v1.InitPaginationRequest\x1a\x32.qwak.feature.store.jobs.v1.InitPaginationResponse\x12\x65\n\x08ListJobs\x12+.qwak.feature.store.jobs.v1.ListJobsRequest\x1a,.qwak.feature.store.jobs.v1.ListJobsResponse\x12\x8f\x01\n\x16GetLatestSuccessfulJob\x12\x39.qwak.feature.store.jobs.v1.GetLatestSuccessfulJobRequest\x1a:.qwak.feature.store.jobs.v1.GetLatestSuccessfulJobResponse\x12\x9b\x01\n\x1aGetAllLatestSuccessfulJobs\x12=.qwak.feature.store.jobs.v1.GetAllLatestSuccessfulJobsRequest\x1a>.qwak.feature.store.jobs.v1.GetAllLatestSuccessfulJobsResponse\x12q\n\x0cGetLatestJob\x12/.qwak.feature.store.jobs.v1.GetLatestJobRequest\x1a\x30.qwak.feature.store.jobs.v1.GetLatestJobResponse\x12\x89\x01\n\x14\x44\x65leteFeaturesetJobs\x12\x37.qwak.feature.store.jobs.v1.DeleteFeaturesetJobsRequest\x1a\x38.qwak.feature.store.jobs.v1.DeleteFeaturesetJobsResponse\x12\x9b\x01\n\x1a\x44\x65leteFeaturesetJobByJobId\x12=.qwak.feature.store.jobs.v1.DeleteFeaturesetJobByJobIdRequest\x1a>.qwak.feature.store.jobs.v1.DeleteFeaturesetJobByJobIdResponse\x12}\n\x10GetJobsSummaries\x12\x33.qwak.feature.store.jobs.v1.GetJobsSummariesRequest\x1a\x34.qwak.feature.store.jobs.v1.GetJobsSummariesResponseB=\n%com.qwak.ai.feature.store.jobs.v1.apiP\x01Z\x12qwak/fsjobs;fsjobsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.jobs.v1.job_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.jobs.v1.apiP\001Z\022qwak/fsjobs;fsjobs'
  _globals['_DELETEFEATURESETJOBBYJOBIDREQUEST']._serialized_start=147
  _globals['_DELETEFEATURESETJOBBYJOBIDREQUEST']._serialized_end=245
  _globals['_DELETEFEATURESETJOBBYJOBIDRESPONSE']._serialized_start=247
  _globals['_DELETEFEATURESETJOBBYJOBIDRESPONSE']._serialized_end=317
  _globals['_APPLYJOBREQUEST']._serialized_start=319
  _globals['_APPLYJOBREQUEST']._serialized_end=395
  _globals['_APPLYJOBRESPONSE']._serialized_start=397
  _globals['_APPLYJOBRESPONSE']._serialized_end=455
  _globals['_INITPAGINATIONREQUEST']._serialized_start=457
  _globals['_INITPAGINATIONREQUEST']._serialized_end=527
  _globals['_INITPAGINATIONRESPONSE']._serialized_start=529
  _globals['_INITPAGINATIONRESPONSE']._serialized_end=610
  _globals['_LISTJOBSREQUEST']._serialized_start=613
  _globals['_LISTJOBSREQUEST']._serialized_end=752
  _globals['_LISTJOBSRESPONSE']._serialized_start=754
  _globals['_LISTJOBSRESPONSE']._serialized_end=825
  _globals['_GETLATESTSUCCESSFULJOBREQUEST']._serialized_start=827
  _globals['_GETLATESTSUCCESSFULJOBREQUEST']._serialized_end=905
  _globals['_GETLATESTJOBREQUEST']._serialized_start=907
  _globals['_GETLATESTJOBREQUEST']._serialized_end=975
  _globals['_GETLATESTJOBRESPONSE']._serialized_start=977
  _globals['_GETLATESTJOBRESPONSE']._serialized_end=1051
  _globals['_GETLATESTSUCCESSFULJOBRESPONSE']._serialized_start=1053
  _globals['_GETLATESTSUCCESSFULJOBRESPONSE']._serialized_end=1152
  _globals['_GETALLLATESTSUCCESSFULJOBSREQUEST']._serialized_start=1154
  _globals['_GETALLLATESTSUCCESSFULJOBSREQUEST']._serialized_end=1189
  _globals['_GETALLLATESTSUCCESSFULJOBSRESPONSE']._serialized_start=1191
  _globals['_GETALLLATESTSUCCESSFULJOBSRESPONSE']._serialized_end=1280
  _globals['_DELETEFEATURESETJOBSREQUEST']._serialized_start=1282
  _globals['_DELETEFEATURESETJOBSREQUEST']._serialized_end=1358
  _globals['_DELETEFEATURESETJOBSRESPONSE']._serialized_start=1360
  _globals['_DELETEFEATURESETJOBSRESPONSE']._serialized_end=1425
  _globals['_GETJOBSSUMMARIESREQUEST']._serialized_start=1428
  _globals['_GETJOBSSUMMARIESREQUEST']._serialized_end=1578
  _globals['_GETJOBSSUMMARIESRESPONSE']._serialized_start=1580
  _globals['_GETJOBSSUMMARIESRESPONSE']._serialized_end=1686
  _globals['_JOBSERVICE']._serialized_start=1689
  _globals['_JOBSERVICE']._serialized_end=2872
# @@protoc_insertion_point(module_scope)



import os
from typing import List, Optional

from pydantic import ConfigDict, Field

from frogml_storage.models.entity_manifest import Artifact, Checksums, EntityManifest
from frogml_storage.models.serialization_metadata import SerializationMetadata


class ModelManifest(EntityManifest):
    """
    Represent a model manifest file

    Attributes:
        model_format: If the entity is model, holds model format information
        dependency_artifacts: If the entity is model, holds a list of files specifying the model dependencies
        code_artifacts: If the entity is model, specifies the archive file artifact
    """

    artifacts: List[Artifact] = Field(serialization_alias="model_artifacts")

    model_format: SerializationMetadata
    dependency_artifacts: Optional[List[Artifact]] = None
    code_artifacts: Optional[Artifact] = None

    # suppress warning on model_format field name.
    # if one day it collides with pydantic field, it will throw an error.
    model_config = ConfigDict(protected_namespaces=())

    def add_dependency_file(
        self, file_path: str, checksums: Checksums, rel_path: str
    ) -> None:
        if self.dependency_artifacts is None:
            self.dependency_artifacts = []
        self.dependency_artifacts.append(
            Artifact(
                artifact_path=rel_path,
                size=os.path.getsize(file_path),
                checksums=checksums,
            )
        )

    def __eq__(self, other):
        if not super.__eq__(self, other):
            return False
        if self.model_format != other.model_format:
            return False
        if self.dependency_artifacts != other.dependency_artifacts:
            return False
        if self.dependency_artifacts is not None:
            if len(self.dependency_artifacts) != len(other.dependency_artifacts):
                return False
            for self_artifact, other_artifact in zip(
                self.dependency_artifacts, other.dependency_artifacts
            ):
                if self_artifact != other_artifact:
                    return False
        if self.code_artifacts != other.code_artifacts:
            return False
        return True



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/vector_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.vectors.v1 import vector_pb2 as qwak_dot_vectors_dot_v1_dot_vector__pb2
from _qwak_proto.qwak.vectors.v1 import filters_pb2 as qwak_dot_vectors_dot_v1_dot_filters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$qwak/vectors/v1/vector_service.proto\x12\x1cqwak.vector.store.serving.v1\x1a\x1cqwak/vectors/v1/vector.proto\x1a\x1dqwak/vectors/v1/filters.proto\"\xd9\x02\n\x1bSearchSimilarVectorsRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x44\n\x10reference_vector\x18\x02 \x01(\x0b\x32*.qwak.vector.store.serving.v1.DoubleVector\x12\x12\n\nproperties\x18\x03 \x03(\t\x12\x36\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.qwak.vector.store.serving.v1.FilterH\x00\x12\x13\n\x0bmax_results\x18\x05 \x01(\x05\x12\x16\n\x0einclude_vector\x18\x06 \x01(\x08\x12\x18\n\x10include_distance\x18\x07 \x01(\x08\x12\x12\n\ninclude_id\x18\x08 \x01(\x08\x12\x13\n\ttenant_id\x18\t \x01(\tH\x01\x42\x0c\n\nfilter_optB\x11\n\x0foptional_tenant\"b\n\x1cSearchSimilarVectorsResponse\x12\x42\n\x0esearch_results\x18\x01 \x03(\x0b\x32*.qwak.vector.store.serving.v1.SearchResult\"\x86\x01\n\x16GetVectorSampleRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x13\n\x0bnum_samples\x18\x02 \x01(\x05\x12\x16\n\x0einclude_vector\x18\x03 \x01(\x08\x12\x13\n\ttenant_id\x18\t \x01(\tH\x00\x42\x11\n\x0foptional_tenant\"V\n\x17GetVectorSampleResponse\x12;\n\x07vectors\x18\x01 \x03(\x0b\x32*.qwak.vector.store.serving.v1.StoredVector\"k\n\x14UpsertVectorsRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12:\n\x06vector\x18\x02 \x03(\x0b\x32*.qwak.vector.store.serving.v1.StoredVector\"-\n\x15UpsertVectorsResponse\x12\x14\n\x0cnum_affected\x18\x01 \x01(\x05\"\x92\x01\n\x14\x44\x65leteVectorsRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x15\n\tvector_id\x18\x02 \x03(\tB\x02\x18\x01\x12J\n\x12vector_identifiers\x18\x03 \x03(\x0b\x32..qwak.vector.store.serving.v1.VectorIdentifier\"4\n\x15\x44\x65leteVectorsResponse\x12\x1b\n\x13num_vectors_deleted\x18\x01 \x01(\x03\"\x8f\x01\n\x12\x46\x65tchVectorRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x15\n\tvector_id\x18\x02 \x01(\tB\x02\x18\x01\x12I\n\x11vector_identifier\x18\x03 \x01(\x0b\x32..qwak.vector.store.serving.v1.VectorIdentifier\"Q\n\x13\x46\x65tchVectorResponse\x12:\n\x06vector\x18\x01 \x01(\x0b\x32*.qwak.vector.store.serving.v1.StoredVector2\x87\x05\n\rVectorService\x12\x8d\x01\n\x14SearchSimilarVectors\x12\x39.qwak.vector.store.serving.v1.SearchSimilarVectorsRequest\x1a:.qwak.vector.store.serving.v1.SearchSimilarVectorsResponse\x12~\n\x0fGetVectorSample\x12\x34.qwak.vector.store.serving.v1.GetVectorSampleRequest\x1a\x35.qwak.vector.store.serving.v1.GetVectorSampleResponse\x12r\n\x0b\x46\x65tchVector\x12\x30.qwak.vector.store.serving.v1.FetchVectorRequest\x1a\x31.qwak.vector.store.serving.v1.FetchVectorResponse\x12x\n\rUpsertVectors\x12\x32.qwak.vector.store.serving.v1.UpsertVectorsRequest\x1a\x33.qwak.vector.store.serving.v1.UpsertVectorsResponse\x12x\n\rDeleteVectors\x12\x32.qwak.vector.store.serving.v1.DeleteVectorsRequest\x1a\x33.qwak.vector.store.serving.v1.DeleteVectorsResponseB\x1e\n\x1a\x63om.qwak.ai.vectors.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.vectors.v1.vector_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.vectors.api.v1P\001'
  _DELETEVECTORSREQUEST.fields_by_name['vector_id']._options = None
  _DELETEVECTORSREQUEST.fields_by_name['vector_id']._serialized_options = b'\030\001'
  _FETCHVECTORREQUEST.fields_by_name['vector_id']._options = None
  _FETCHVECTORREQUEST.fields_by_name['vector_id']._serialized_options = b'\030\001'
  _globals['_SEARCHSIMILARVECTORSREQUEST']._serialized_start=132
  _globals['_SEARCHSIMILARVECTORSREQUEST']._serialized_end=477
  _globals['_SEARCHSIMILARVECTORSRESPONSE']._serialized_start=479
  _globals['_SEARCHSIMILARVECTORSRESPONSE']._serialized_end=577
  _globals['_GETVECTORSAMPLEREQUEST']._serialized_start=580
  _globals['_GETVECTORSAMPLEREQUEST']._serialized_end=714
  _globals['_GETVECTORSAMPLERESPONSE']._serialized_start=716
  _globals['_GETVECTORSAMPLERESPONSE']._serialized_end=802
  _globals['_UPSERTVECTORSREQUEST']._serialized_start=804
  _globals['_UPSERTVECTORSREQUEST']._serialized_end=911
  _globals['_UPSERTVECTORSRESPONSE']._serialized_start=913
  _globals['_UPSERTVECTORSRESPONSE']._serialized_end=958
  _globals['_DELETEVECTORSREQUEST']._serialized_start=961
  _globals['_DELETEVECTORSREQUEST']._serialized_end=1107
  _globals['_DELETEVECTORSRESPONSE']._serialized_start=1109
  _globals['_DELETEVECTORSRESPONSE']._serialized_end=1161
  _globals['_FETCHVECTORREQUEST']._serialized_start=1164
  _globals['_FETCHVECTORREQUEST']._serialized_end=1307
  _globals['_FETCHVECTORRESPONSE']._serialized_start=1309
  _globals['_FETCHVECTORRESPONSE']._serialized_end=1390
  _globals['_VECTORSERVICE']._serialized_start=1393
  _globals['_VECTORSERVICE']._serialized_end=2040
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LogsStorageConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELASTICSEARCH_FIELD_NUMBER: builtins.int
    @property
    def elasticsearch(self) -> qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2.ElasticsearchConfiguration: ...
    def __init__(
        self,
        *,
        elasticsearch: qwak.administration.runtime_configuration.v0.external.elasticsearch_config_pb2.ElasticsearchConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elasticsearch", b"elasticsearch", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elasticsearch", b"elasticsearch", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["elasticsearch"] | None: ...

global___LogsStorageConfiguration = LogsStorageConfiguration



from typing import Optional

import grpc

from _qwak_proto.qwak.administration.v0.environments.environment_pb2 import (
    QwakEnvironment,
)
from _qwak_proto.qwak.administration.v1.environments.environment_service_pb2 import (
    CreateEnvironmentResponse,
)
from _qwak_proto.qwak.administration.v1.environments.environment_service_pb2_grpc import (
    EnvironmentServiceServicer,
)


class EnvironmentV1ServiceMock(EnvironmentServiceServicer):
    def __init__(self):
        super().__init__()
        self.__create_environment_response: Optional[CreateEnvironmentResponse] = None
        self.__create_environment_error: Optional[grpc.StatusCode] = None

    def given_create_environment(
        self,
        response: Optional[CreateEnvironmentResponse] = None,
        error_code: Optional[grpc.StatusCode] = None,
    ):
        self.__create_environment_response = response
        self.__create_environment_error = error_code

    def CreateEnvironment(self, request, context):
        if self.__create_environment_error:
            context.set_code(self.__create_environment_error)
            context.set_details("Failed to create environment")
            return CreateEnvironmentResponse()
        if self.__create_environment_response:
            return self.__create_environment_response
        return CreateEnvironmentResponse(environment=QwakEnvironment(id="mock-env-id"))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/entities/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/feature_store/entities/entity.proto\x12\x1bqwak.feature.store.entities\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x01\n\x06\x45ntity\x12H\n\x11\x65ntity_definition\x18\x01 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\x12=\n\x08metadata\x18\x02 \x01(\x0b\x32+.qwak.feature.store.entities.EntityMetadata\x12\x42\n\x0c\x66\x65\x61ture_sets\x18\x03 \x03(\x0b\x32,.qwak.feature.store.entities.FeatureSetBrief\"c\n\x10\x45ntityDefinition\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12<\n\x0b\x65ntity_spec\x18\x02 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"\xa4\x01\n\x0e\x45ntityMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\xb3\x01\n\nEntitySpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x45\n\nvalue_type\x18\x04 \x01(\x0e\x32\x31.qwak.feature.store.entities.EntitySpec.ValueType\"-\n\tValueType\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x07\n\x03INT\x10\x02\"C\n\x0f\x46\x65\x61tureSetBrief\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\tB[\n&com.qwak.ai.feature.store.entities.apiP\x01Z/qwak/featurestore/entities;featurestoreentitiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.entities.entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.entities.apiP\001Z/qwak/featurestore/entities;featurestoreentities'
  _globals['_ENTITY']._serialized_start=107
  _globals['_ENTITY']._serialized_end=320
  _globals['_ENTITYDEFINITION']._serialized_start=322
  _globals['_ENTITYDEFINITION']._serialized_end=421
  _globals['_ENTITYMETADATA']._serialized_start=424
  _globals['_ENTITYMETADATA']._serialized_end=588
  _globals['_ENTITYSPEC']._serialized_start=591
  _globals['_ENTITYSPEC']._serialized_end=770
  _globals['_ENTITYSPEC_VALUETYPE']._serialized_start=725
  _globals['_ENTITYSPEC_VALUETYPE']._serialized_end=770
  _globals['_FEATURESETBRIEF']._serialized_start=772
  _globals['_FEATURESETBRIEF']._serialized_end=839
# @@protoc_insertion_point(module_scope)



"""Environment V1 API client.

Provides wrapper methods for the Environment V1 gRPC service with proper error handling.
"""

from _qwak_proto.qwak.administration.v1.environments.environment_pb2 import (
    EnvironmentRuntimeConfigSpec,
)
from _qwak_proto.qwak.administration.v1.environments.environment_service_pb2 import (
    CreateEnvironmentRequest,
    CreateEnvironmentResponse,
)
from _qwak_proto.qwak.administration.v1.environments.environment_service_pb2_grpc import (
    EnvironmentServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.inner.di_configuration import QwakContainer
from qwak.inner.tool.grpc.grpc_try_wrapping import grpc_try_catch_wrapper


class EnvironmentV1Client:
    """Client for interacting with the Environment V1 API.

    This client wraps the gRPC stub and provides methods with proper error handling
    using the grpc_try_catch_wrapper decorator.
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self.__environment_service = EnvironmentServiceStub(grpc_channel)

    @grpc_try_catch_wrapper("Failed to create environment {environment_name}")
    def create_environment(
        self,
        environment_name: str,
        cluster_id: str,
        spec: EnvironmentRuntimeConfigSpec,
    ) -> CreateEnvironmentResponse:
        """Create a new environment.

        Args:
            environment_name: The name of the environment.
            cluster_id: The cluster ID the environment belongs to.
            spec: The environment runtime configuration specification.

        Returns:
            CreateEnvironmentResponse with the created environment.
        """
        request = CreateEnvironmentRequest(
            environment_name=environment_name,
            cluster_id=cluster_id,
            spec=spec,
        )
        return self.__environment_service.CreateEnvironment(request)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import qwak.self_service.user.v1.api_key_pb2
import qwak.self_service.user.v1.user_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenerateApiKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    FORCE_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """User id to generate API key for"""
    environment_id: builtins.str
    """Environment ID to generate API key for"""
    force: builtins.bool
    """Will override the apikey if exists."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        force: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "force", b"force", "user_id", b"user_id"]) -> None: ...

global___GenerateApiKeyRequest = GenerateApiKeyRequest

class GenerateApiKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    api_key: builtins.str
    """Generated API Key"""
    def __init__(
        self,
        *,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key"]) -> None: ...

global___GenerateApiKeyResponse = GenerateApiKeyResponse

class RevokeApiKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """User ID whose API Key should be revoked"""
    environment_id: builtins.str
    """Environment ID of the user to reset the password for"""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "user_id", b"user_id"]) -> None: ...

global___RevokeApiKeyRequest = RevokeApiKeyRequest

class RevokeApiKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RevokeApiKeyResponse._Status.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID_USER_STATUS: RevokeApiKeyResponse._Status.ValueType  # 0
        """Invalid status"""
        REVOKED: RevokeApiKeyResponse._Status.ValueType  # 1
        """Marks the API Key was revoked successfully"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    INVALID_USER_STATUS: RevokeApiKeyResponse.Status.ValueType  # 0
    """Invalid status"""
    REVOKED: RevokeApiKeyResponse.Status.ValueType  # 1
    """Marks the API Key was revoked successfully"""

    STATUS_FIELD_NUMBER: builtins.int
    status: global___RevokeApiKeyResponse.Status.ValueType
    """Revoke response status"""
    def __init__(
        self,
        *,
        status: global___RevokeApiKeyResponse.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___RevokeApiKeyResponse = RevokeApiKeyResponse

class ListApiKeyDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListApiKeyDetailsRequest = ListApiKeyDetailsRequest

class ListApiKeyDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentToApiKeyDetailsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.self_service.user.v1.api_key_pb2.ApiKeyDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.self_service.user.v1.api_key_pb2.ApiKeyDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENVIRONMENT_TO_API_KEY_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def environment_to_api_key_details(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.self_service.user.v1.api_key_pb2.ApiKeyDetails]:
        """Environment ids to their API key details"""
    def __init__(
        self,
        *,
        environment_to_api_key_details: collections.abc.Mapping[builtins.str, qwak.self_service.user.v1.api_key_pb2.ApiKeyDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_to_api_key_details", b"environment_to_api_key_details"]) -> None: ...

global___ListApiKeyDetailsResponse = ListApiKeyDetailsResponse

class GetUserProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetUserProfileRequest = GetUserProfileRequest

class GetUserProfileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile: ...
    def __init__(
        self,
        *,
        user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> None: ...

global___GetUserProfileResponse = GetUserProfileResponse

class UpdateUserProfileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile: ...
    def __init__(
        self,
        *,
        user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> None: ...

global___UpdateUserProfileRequest = UpdateUserProfileRequest

class UpdateUserProfileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATED_USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def updated_user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile: ...
    def __init__(
        self,
        *,
        updated_user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["updated_user_profile", b"updated_user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["updated_user_profile", b"updated_user_profile"]) -> None: ...

global___UpdateUserProfileResponse = UpdateUserProfileResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/collection/collection_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.vectors.v1.collection import collection_pb2 as qwak_dot_vectors_dot_v1_dot_collection_dot_collection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/vectors/v1/collection/collection_service.proto\x12\x1fqwak.vector.store.v1.collection\x1a+qwak/vectors/v1/collection/collection.proto\"i\n\x17\x43reateCollectionRequest\x12N\n\x0f\x63ollection_spec\x18\x01 \x01(\x0b\x32\x35.qwak.vector.store.v1.collection.VectorCollectionSpec\"h\n\x18\x43reateCollectionResponse\x12L\n\x11vector_collection\x18\x01 \x01(\x0b\x32\x31.qwak.vector.store.v1.collection.VectorCollection\"u\n\x17UpdateCollectionRequest\x12Z\n\x15\x63ollection_definition\x18\x01 \x01(\x0b\x32;.qwak.vector.store.v1.collection.VectorCollectionDefinition\"h\n\x18UpdateCollectionResponse\x12L\n\x11vector_collection\x18\x01 \x01(\x0b\x32\x31.qwak.vector.store.v1.collection.VectorCollection\"&\n\x18GetCollectionByIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\xbb\x01\n\x19GetCollectionByIdResponse\x12L\n\x11vector_collection\x18\x01 \x01(\x0b\x32\x31.qwak.vector.store.v1.collection.VectorCollection\x12P\n\x13\x63ollection_metadata\x18\x02 \x01(\x0b\x32\x33.qwak.vector.store.v1.collection.CollectionMetadata\"*\n\x1aGetCollectionByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xbd\x01\n\x1bGetCollectionByNameResponse\x12L\n\x11vector_collection\x18\x01 \x01(\x0b\x32\x31.qwak.vector.store.v1.collection.VectorCollection\x12P\n\x13\x63ollection_metadata\x18\x02 \x01(\x0b\x32\x33.qwak.vector.store.v1.collection.CollectionMetadata\")\n\x1b\x44\x65leteCollectionByIdRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1e\n\x1c\x44\x65leteCollectionByIdResponse\"-\n\x1d\x44\x65leteCollectionByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x1e\x44\x65leteCollectionByNameResponse\"\x18\n\x16ListCollectionsRequest\"h\n\x17ListCollectionsResponse\x12M\n\x12vector_collections\x18\x01 \x03(\x0b\x32\x31.qwak.vector.store.v1.collection.VectorCollection\"\x1b\n\x19GetCollectionCountRequest\"6\n\x1aGetCollectionCountResponse\x12\x18\n\x10\x63ollection_count\x18\x01 \x01(\x05\x32\x96\t\n\x17VectorCollectionService\x12\x87\x01\n\x10\x43reateCollection\x12\x38.qwak.vector.store.v1.collection.CreateCollectionRequest\x1a\x39.qwak.vector.store.v1.collection.CreateCollectionResponse\x12\x87\x01\n\x10UpdateCollection\x12\x38.qwak.vector.store.v1.collection.UpdateCollectionRequest\x1a\x39.qwak.vector.store.v1.collection.UpdateCollectionResponse\x12\x8a\x01\n\x11GetCollectionById\x12\x39.qwak.vector.store.v1.collection.GetCollectionByIdRequest\x1a:.qwak.vector.store.v1.collection.GetCollectionByIdResponse\x12\x90\x01\n\x13GetCollectionByName\x12;.qwak.vector.store.v1.collection.GetCollectionByNameRequest\x1a<.qwak.vector.store.v1.collection.GetCollectionByNameResponse\x12\x93\x01\n\x14\x44\x65leteCollectionById\x12<.qwak.vector.store.v1.collection.DeleteCollectionByIdRequest\x1a=.qwak.vector.store.v1.collection.DeleteCollectionByIdResponse\x12\x99\x01\n\x16\x44\x65leteCollectionByName\x12>.qwak.vector.store.v1.collection.DeleteCollectionByNameRequest\x1a?.qwak.vector.store.v1.collection.DeleteCollectionByNameResponse\x12\x84\x01\n\x0fListCollections\x12\x37.qwak.vector.store.v1.collection.ListCollectionsRequest\x1a\x38.qwak.vector.store.v1.collection.ListCollectionsResponse\x12\x8d\x01\n\x12GetCollectionCount\x12:.qwak.vector.store.v1.collection.GetCollectionCountRequest\x1a;.qwak.vector.store.v1.collection.GetCollectionCountResponseB%\n!com.qwak.ai.vectors.v1.collectionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.vectors.v1.collection.collection_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.vectors.v1.collectionP\001'
  _globals['_CREATECOLLECTIONREQUEST']._serialized_start=133
  _globals['_CREATECOLLECTIONREQUEST']._serialized_end=238
  _globals['_CREATECOLLECTIONRESPONSE']._serialized_start=240
  _globals['_CREATECOLLECTIONRESPONSE']._serialized_end=344
  _globals['_UPDATECOLLECTIONREQUEST']._serialized_start=346
  _globals['_UPDATECOLLECTIONREQUEST']._serialized_end=463
  _globals['_UPDATECOLLECTIONRESPONSE']._serialized_start=465
  _globals['_UPDATECOLLECTIONRESPONSE']._serialized_end=569
  _globals['_GETCOLLECTIONBYIDREQUEST']._serialized_start=571
  _globals['_GETCOLLECTIONBYIDREQUEST']._serialized_end=609
  _globals['_GETCOLLECTIONBYIDRESPONSE']._serialized_start=612
  _globals['_GETCOLLECTIONBYIDRESPONSE']._serialized_end=799
  _globals['_GETCOLLECTIONBYNAMEREQUEST']._serialized_start=801
  _globals['_GETCOLLECTIONBYNAMEREQUEST']._serialized_end=843
  _globals['_GETCOLLECTIONBYNAMERESPONSE']._serialized_start=846
  _globals['_GETCOLLECTIONBYNAMERESPONSE']._serialized_end=1035
  _globals['_DELETECOLLECTIONBYIDREQUEST']._serialized_start=1037
  _globals['_DELETECOLLECTIONBYIDREQUEST']._serialized_end=1078
  _globals['_DELETECOLLECTIONBYIDRESPONSE']._serialized_start=1080
  _globals['_DELETECOLLECTIONBYIDRESPONSE']._serialized_end=1110
  _globals['_DELETECOLLECTIONBYNAMEREQUEST']._serialized_start=1112
  _globals['_DELETECOLLECTIONBYNAMEREQUEST']._serialized_end=1157
  _globals['_DELETECOLLECTIONBYNAMERESPONSE']._serialized_start=1159
  _globals['_DELETECOLLECTIONBYNAMERESPONSE']._serialized_end=1191
  _globals['_LISTCOLLECTIONSREQUEST']._serialized_start=1193
  _globals['_LISTCOLLECTIONSREQUEST']._serialized_end=1217
  _globals['_LISTCOLLECTIONSRESPONSE']._serialized_start=1219
  _globals['_LISTCOLLECTIONSRESPONSE']._serialized_end=1323
  _globals['_GETCOLLECTIONCOUNTREQUEST']._serialized_start=1325
  _globals['_GETCOLLECTIONCOUNTREQUEST']._serialized_end=1352
  _globals['_GETCOLLECTIONCOUNTRESPONSE']._serialized_start=1354
  _globals['_GETCOLLECTIONCOUNTRESPONSE']._serialized_end=1408
  _globals['_VECTORCOLLECTIONSERVICE']._serialized_start=1411
  _globals['_VECTORCOLLECTIONSERVICE']._serialized_end=2585
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.sources import data_source_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/feature_store/sources/data_source_service.proto\x12\x1aqwak.feature.store.sources\x1a,qwak/feature_store/sources/data_source.proto\"_\n\x17\x43reateDataSourceRequest\x12\x44\n\x10\x64\x61ta_source_spec\x18\x01 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"W\n\x18\x43reateDataSourceResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"w\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"W\n\x18UpdateDataSourceResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"1\n\x17\x44\x65leteDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"2\n\x18GetDataSourceByIdRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"X\n\x19GetDataSourceByIdResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"6\n\x1aGetDataSourceByNameRequest\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\"Z\n\x1bGetDataSourceByNameResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"\x18\n\x16ListDataSourcesRequest\"W\n\x17ListDataSourcesResponse\x12<\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32&.qwak.feature.store.sources.DataSource\"!\n\x1fListDataSourcesByAccountRequest\"`\n ListDataSourcesByAccountResponse\x12<\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32&.qwak.feature.store.sources.DataSource\"Q\n CreateDataSourceUploadURLRequest\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\x12\x13\n\x0bobject_name\x18\x02 \x01(\t\"7\n!CreateDataSourceUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t2\xed\t\n\x11\x44\x61taSourceService\x12}\n\x10\x43reateDataSource\x12\x33.qwak.feature.store.sources.CreateDataSourceRequest\x1a\x34.qwak.feature.store.sources.CreateDataSourceResponse\x12}\n\x10UpdateDataSource\x12\x33.qwak.feature.store.sources.UpdateDataSourceRequest\x1a\x34.qwak.feature.store.sources.UpdateDataSourceResponse\x12}\n\x10\x44\x65leteDataSource\x12\x33.qwak.feature.store.sources.DeleteDataSourceRequest\x1a\x34.qwak.feature.store.sources.DeleteDataSourceResponse\x12\x80\x01\n\x11GetDataSourceById\x12\x34.qwak.feature.store.sources.GetDataSourceByIdRequest\x1a\x35.qwak.feature.store.sources.GetDataSourceByIdResponse\x12\x86\x01\n\x13GetDataSourceByName\x12\x36.qwak.feature.store.sources.GetDataSourceByNameRequest\x1a\x37.qwak.feature.store.sources.GetDataSourceByNameResponse\x12z\n\x0fListDataSources\x12\x32.qwak.feature.store.sources.ListDataSourcesRequest\x1a\x33.qwak.feature.store.sources.ListDataSourcesResponse\x12\x95\x01\n\x18ListDataSourcesByAccount\x12;.qwak.feature.store.sources.ListDataSourcesByAccountRequest\x1a<.qwak.feature.store.sources.ListDataSourcesByAccountResponse\x12\x9d\x01\n\x19\x43reateDataSourceUploadURL\x12<.qwak.feature.store.sources.CreateDataSourceUploadURLRequest\x1a=.qwak.feature.store.sources.CreateDataSourceUploadURLResponse\"\x03\x88\x02\x01\x12\x9a\x01\n\x1b\x43reateDataSourceUploadURLV1\x12<.qwak.feature.store.sources.CreateDataSourceUploadURLRequest\x1a=.qwak.feature.store.sources.CreateDataSourceUploadURLResponseB[\n(com.qwak.ai.feature.store.management.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sources.data_source_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCESERVICE.methods_by_name['CreateDataSourceUploadURL']._options = None
  _DATASOURCESERVICE.methods_by_name['CreateDataSourceUploadURL']._serialized_options = b'\210\002\001'
  _globals['_CREATEDATASOURCEREQUEST']._serialized_start=130
  _globals['_CREATEDATASOURCEREQUEST']._serialized_end=225
  _globals['_CREATEDATASOURCERESPONSE']._serialized_start=227
  _globals['_CREATEDATASOURCERESPONSE']._serialized_end=314
  _globals['_UPDATEDATASOURCEREQUEST']._serialized_start=316
  _globals['_UPDATEDATASOURCEREQUEST']._serialized_end=435
  _globals['_UPDATEDATASOURCERESPONSE']._serialized_start=437
  _globals['_UPDATEDATASOURCERESPONSE']._serialized_end=524
  _globals['_DELETEDATASOURCEREQUEST']._serialized_start=526
  _globals['_DELETEDATASOURCEREQUEST']._serialized_end=575
  _globals['_DELETEDATASOURCERESPONSE']._serialized_start=577
  _globals['_DELETEDATASOURCERESPONSE']._serialized_end=603
  _globals['_GETDATASOURCEBYIDREQUEST']._serialized_start=605
  _globals['_GETDATASOURCEBYIDREQUEST']._serialized_end=655
  _globals['_GETDATASOURCEBYIDRESPONSE']._serialized_start=657
  _globals['_GETDATASOURCEBYIDRESPONSE']._serialized_end=745
  _globals['_GETDATASOURCEBYNAMEREQUEST']._serialized_start=747
  _globals['_GETDATASOURCEBYNAMEREQUEST']._serialized_end=801
  _globals['_GETDATASOURCEBYNAMERESPONSE']._serialized_start=803
  _globals['_GETDATASOURCEBYNAMERESPONSE']._serialized_end=893
  _globals['_LISTDATASOURCESREQUEST']._serialized_start=895
  _globals['_LISTDATASOURCESREQUEST']._serialized_end=919
  _globals['_LISTDATASOURCESRESPONSE']._serialized_start=921
  _globals['_LISTDATASOURCESRESPONSE']._serialized_end=1008
  _globals['_LISTDATASOURCESBYACCOUNTREQUEST']._serialized_start=1010
  _globals['_LISTDATASOURCESBYACCOUNTREQUEST']._serialized_end=1043
  _globals['_LISTDATASOURCESBYACCOUNTRESPONSE']._serialized_start=1045
  _globals['_LISTDATASOURCESBYACCOUNTRESPONSE']._serialized_end=1141
  _globals['_CREATEDATASOURCEUPLOADURLREQUEST']._serialized_start=1143
  _globals['_CREATEDATASOURCEUPLOADURLREQUEST']._serialized_end=1224
  _globals['_CREATEDATASOURCEUPLOADURLRESPONSE']._serialized_start=1226
  _globals['_CREATEDATASOURCEUPLOADURLRESPONSE']._serialized_end=1281
  _globals['_DATASOURCESERVICE']._serialized_start=1284
  _globals['_DATASOURCESERVICE']._serialized_end=2545
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PopulationFileUploadUrlType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PopulationFileUploadUrlType = PopulationFileUploadUrlType

class TimedPopulation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_COLUMN_NAME_FIELD_NUMBER: builtins.int
    POPULATION_FIELD_NUMBER: builtins.int
    timestamp_column_name: builtins.str
    """The name of the timestamp column"""
    @property
    def population(self) -> global___Population:
        """The population dataset"""
    def __init__(
        self,
        *,
        timestamp_column_name: builtins.str = ...,
        population: global___Population | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["population", b"population"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["population", b"population", "timestamp_column_name", b"timestamp_column_name"]) -> None: ...

global___TimedPopulation = TimedPopulation

class Population(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POPULATION_FILE_FIELD_NUMBER: builtins.int
    @property
    def population_file(self) -> global___PopulationFile:
        """Reference to population dataset file"""
    def __init__(
        self,
        *,
        population_file: global___PopulationFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["population_file", b"population_file", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["population_file", b"population_file", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["population_file"] | None: ...

global___Population = Population

class PopulationFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_URL_FIELD_NUMBER: builtins.int
    ARROW_SCHEMA_JSON_FIELD_NUMBER: builtins.int
    file_url: builtins.str
    """Population dataset file url"""
    @property
    def arrow_schema_json(self) -> global___ArrowSchemaJson: ...
    def __init__(
        self,
        *,
        file_url: builtins.str = ...,
        arrow_schema_json: global___ArrowSchemaJson | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arrow_schema_json", b"arrow_schema_json", "schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arrow_schema_json", b"arrow_schema_json", "file_url", b"file_url", "schema", b"schema"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["schema", b"schema"]) -> typing_extensions.Literal["arrow_schema_json"] | None: ...

global___PopulationFile = PopulationFile

class ArrowSchemaJson(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_FIELD_NUMBER: builtins.int
    schema: builtins.str
    """Schema represented as json with arrow types e.g. {"col1": "double", "clo2": {"list": {"list": "int64"}}, "col3": {"struct": [{"field1": {"struct": [{"field1": "string"}]}}}"""
    def __init__(
        self,
        *,
        schema: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["schema", b"schema"]) -> None: ...

global___ArrowSchemaJson = ArrowSchemaJson



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v1/environments/environment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.v0.environments import environment_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_environment__pb2
from _qwak_proto.qwak.administration.v1.environments import environment_pb2 as qwak_dot_administration_dot_v1_dot_environments_dot_environment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=qwak/administration/v1/environments/environment_service.proto\x12\"qwak.administration.v1.environment\x1a\x35qwak/administration/v0/environments/environment.proto\x1a\x35qwak/administration/v1/environments/environment.proto\"\x98\x01\n\x18\x43reateEnvironmentRequest\x12\x18\n\x10\x65nvironment_name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12N\n\x04spec\x18\x03 \x01(\x0b\x32@.qwak.administration.v1.environment.EnvironmentRuntimeConfigSpec\"b\n\x19\x43reateEnvironmentResponse\x12\x45\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x30.qwak.administration.environment.QwakEnvironment2\xa7\x01\n\x12\x45nvironmentService\x12\x90\x01\n\x11\x43reateEnvironment\x12<.qwak.administration.v1.environment.CreateEnvironmentRequest\x1a=.qwak.administration.v1.environment.CreateEnvironmentResponseB\xb5\x01\n!com.qwak.ai.administration.v1.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v1/environments;environment_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.v1.environments.environment_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.administration.v1.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v1/environments;environment_v1'
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_start=212
  _globals['_CREATEENVIRONMENTREQUEST']._serialized_end=364
  _globals['_CREATEENVIRONMENTRESPONSE']._serialized_start=366
  _globals['_CREATEENVIRONMENTRESPONSE']._serialized_end=464
  _globals['_ENVIRONMENTSERVICE']._serialized_start=467
  _globals['_ENVIRONMENTSERVICE']._serialized_end=634
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExecutionStatusMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExecutionStatusMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExecutionStatusMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED: _ExecutionStatusMessage.ValueType  # 0
    RUNNING: _ExecutionStatusMessage.ValueType  # 1
    SUCCESSFUL: _ExecutionStatusMessage.ValueType  # 2
    FAILED: _ExecutionStatusMessage.ValueType  # 3

class ExecutionStatusMessage(_ExecutionStatusMessage, metaclass=_ExecutionStatusMessageEnumTypeWrapper): ...

UNDEFINED: ExecutionStatusMessage.ValueType  # 0
RUNNING: ExecutionStatusMessage.ValueType  # 1
SUCCESSFUL: ExecutionStatusMessage.ValueType  # 2
FAILED: ExecutionStatusMessage.ValueType  # 3
global___ExecutionStatusMessage = ExecutionStatusMessage

class AutomationExecutionMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    RUN_DETAILS_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """The automation execution id"""
    @property
    def run_details(self) -> global___ExecutionRunDetailsMessage:
        """The automation run details"""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
        run_details: global___ExecutionRunDetailsMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["run_details", b"run_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id", "run_details", b"run_details"]) -> None: ...

global___AutomationExecutionMessage = AutomationExecutionMessage

class ExecutionRunDetailsMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    ERROR_DETAILS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    FINISH_CAUSE_FIELD_NUMBER: builtins.int
    LAST_UPDATE_DATE_FIELD_NUMBER: builtins.int
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The start time of the execution run."""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The end time of the execution run."""
    error_details: builtins.str
    """The error details of the execution run."""
    status: global___ExecutionStatusMessage.ValueType
    """The status the execution run."""
    task: builtins.str
    """The task the execution is on."""
    finish_cause: builtins.str
    """The finish cause of the automation."""
    @property
    def last_update_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The last update time of the execution."""
    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        error_details: builtins.str = ...,
        status: global___ExecutionStatusMessage.ValueType = ...,
        task: builtins.str = ...,
        finish_cause: builtins.str = ...,
        last_update_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "last_update_date", b"last_update_date", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "error_details", b"error_details", "finish_cause", b"finish_cause", "last_update_date", b"last_update_date", "start_time", b"start_time", "status", b"status", "task", b"task"]) -> None: ...

global___ExecutionRunDetailsMessage = ExecutionRunDetailsMessage

class DateRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    @property
    def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start date"""
    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End date"""
    def __init__(
        self,
        *,
        start_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> None: ...

global___DateRange = DateRange



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/logging/log_reader_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.logging import log_filter_pb2 as qwak_dot_logging_dot_log__filter__pb2
from _qwak_proto.qwak.logging import log_source_pb2 as qwak_dot_logging_dot_log__source__pb2
from _qwak_proto.qwak.logging import log_line_pb2 as qwak_dot_logging_dot_log__line__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/logging/log_reader_service.proto\x12\x14qwak.logging.service\x1a\x1dqwak/logging/log_filter.proto\x1a\x1dqwak/logging/log_source.proto\x1a\x1bqwak/logging/log_line.proto\"\xd7\x01\n\x0fReadLogsRequest\x12/\n\x06source\x18\x01 \x01(\x0b\x32\x1f.qwak.logging.service.LogSource\x12\x17\n\rbefore_offset\x18\x02 \x01(\tH\x00\x12\x16\n\x0c\x61\x66ter_offset\x18\x03 \x01(\tH\x00\x12\x39\n\rsearch_filter\x18\x04 \x01(\x0b\x32\".qwak.logging.service.SearchFilter\x12\x1d\n\x15max_number_of_results\x18\x05 \x01(\x05\x42\x08\n\x06offset\"\x85\x01\n\x10ReadLogsResponse\x12/\n\x08log_line\x18\x01 \x03(\x0b\x32\x1d.qwak.logging.service.LogLine\x12\x14\n\x0c\x66irst_offset\x18\x02 \x01(\t\x12\x13\n\x0blast_offset\x18\x03 \x01(\t\x12\x15\n\rhas_next_page\x18\x04 \x01(\x08\x32m\n\x10LogReaderService\x12Y\n\x08ReadLogs\x12%.qwak.logging.service.ReadLogsRequest\x1a&.qwak.logging.service.ReadLogsResponseB\"\n\x1e\x63om.qwak.ai.logging.reader.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.logging.log_reader_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.logging.reader.apiP\001'
  _globals['_READLOGSREQUEST']._serialized_start=155
  _globals['_READLOGSREQUEST']._serialized_end=370
  _globals['_READLOGSRESPONSE']._serialized_start=373
  _globals['_READLOGSRESPONSE']._serialized_end=506
  _globals['_LOGREADERSERVICE']._serialized_start=508
  _globals['_LOGREADERSERVICE']._serialized_end=617
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from jfml.hosting_gateway.v1 import hosting_gateway_service_pb2 as jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2


class HostingGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBuildVersioningUploadURL = channel.unary_unary(
                '/jfml.hosting_gateway.v1.HostingGatewayService/GetBuildVersioningUploadURL',
                request_serializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
                response_deserializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
                )


class HostingGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetBuildVersioningUploadURL(self, request, context):
        """Request the service for a path ready for upload in purpose of uploading local model code or data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HostingGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetBuildVersioningUploadURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBuildVersioningUploadURL,
                    request_deserializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLRequest.FromString,
                    response_serializer=jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'jfml.hosting_gateway.v1.HostingGatewayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HostingGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetBuildVersioningUploadURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/jfml.hosting_gateway.v1.HostingGatewayService/GetBuildVersioningUploadURL',
            jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLRequest.SerializeToString,
            jfml_dot_hosting__gateway_dot_v1_dot_hosting__gateway__service__pb2.GetBuildVersioningUploadURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.sources import batch_pb2 as qwak_dot_feature__store_dot_sources_dot_batch__pb2
from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2
from _qwak_proto.qwak.feature_store.features import execution_pb2 as qwak_dot_feature__store_dot_features_dot_execution__pb2
from _qwak_proto.qwak.feature_store.features import aggregation_pb2 as qwak_dot_feature__store_dot_features_dot_aggregation__pb2
from _qwak_proto.qwak.feature_store.features import monitoring_pb2 as qwak_dot_feature__store_dot_features_dot_monitoring__pb2
from _qwak_proto.qwak.feature_store.features import real_time_feature_extractor_pb2 as qwak_dot_feature__store_dot_features_dot_real__time__feature__extractor__pb2
from _qwak_proto.qwak.feature_store.sinks import sink_pb2 as qwak_dot_feature__store_dot_sinks_dot_sink__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/feature_store/features/feature_set_types.proto\x12\x1bqwak.feature.store.features\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&qwak/feature_store/sources/batch.proto\x1a*qwak/feature_store/sources/streaming.proto\x1a+qwak/feature_store/features/execution.proto\x1a-qwak/feature_store/features/aggregation.proto\x1a,qwak/feature_store/features/monitoring.proto\x1a=qwak/feature_store/features/real_time_feature_extractor.proto\x1a#qwak/feature_store/sinks/sink.proto\"\x9f\x04\n\x0e\x46\x65\x61tureSetType\x12I\n\x11\x62\x61tch_feature_set\x18\x05 \x01(\x0b\x32,.qwak.feature.store.features.BatchFeatureSetH\x00\x12Q\n\x16on_the_fly_feature_set\x18\x06 \x01(\x0b\x32/.qwak.feature.store.features.OnTheFlyFeatureSetH\x00\x12Q\n\x15streaming_feature_set\x18\x07 \x01(\x0b\x32\x30.qwak.feature.store.features.StreamingFeatureSetH\x00\x12V\n\x18streaming_feature_set_v1\x18\x08 \x01(\x0b\x32\x32.qwak.feature.store.features.StreamingFeatureSetV1H\x00\x12N\n\x14\x62\x61tch_feature_set_v1\x18\t \x01(\x0b\x32..qwak.feature.store.features.BatchFeatureSetV1H\x00\x12h\n!streaming_aggregation_feature_set\x18\n \x01(\x0b\x32;.qwak.feature.store.features.StreamingAggregationFeatureSetH\x00\x42\n\n\x08set_type\"\x9d\x03\n\x0f\x42\x61tchFeatureSet\x12\x19\n\x11scheduling_policy\x18\x01 \x01(\t\x12\x41\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\'.qwak.feature.store.sources.BatchSourceB\x02\x18\x01\x12\x37\n\x08\x62\x61\x63kfill\x18\x03 \x01(\x0b\x32%.qwak.feature.store.features.Backfill\x12\x37\n\x08\x66unction\x18\x04 \x01(\x0b\x32%.qwak.feature.store.features.Function\x12U\n\x19\x66\x65\x61ture_set_batch_sources\x18\x05 \x03(\x0b\x32\x32.qwak.feature.store.features.FeatureSetBatchSource\x12\x63\n\x19monitoring_configurations\x18\x06 \x01(\x0b\x32@.qwak.feature.store.features.monitoring.MonitoringConfigurations\"\xab\x06\n\x11\x42\x61tchFeatureSetV1\x12\x19\n\x11scheduling_policy\x18\x01 \x01(\t\x12\x37\n\x08\x62\x61\x63kfill\x18\x02 \x01(\x0b\x32%.qwak.feature.store.features.Backfill\x12;\n\x08\x66unction\x18\x03 \x01(\x0b\x32%.qwak.feature.store.features.FunctionB\x02\x18\x01\x12U\n\x19\x66\x65\x61ture_set_batch_sources\x18\x04 \x03(\x0b\x32\x32.qwak.feature.store.features.FeatureSetBatchSource\x12L\n\x0e\x65xecution_spec\x18\x05 \x01(\x0b\x32\x34.qwak.feature.store.features.execution.ExecutionSpec\x12\x14\n\x0coffline_sink\x18\x06 \x01(\x08\x12\x13\n\x0bonline_sink\x18\x07 \x01(\x08\x12\x63\n\x19monitoring_configurations\x18\x08 \x01(\x0b\x32@.qwak.feature.store.features.monitoring.MonitoringConfigurations\x12\x1d\n\x15timestamp_column_name\x18\t \x01(\t\x12\x43\n\x0etransformation\x18\n \x01(\x0b\x32+.qwak.feature.store.features.Transformation\x12&\n\x1eqwak_internal_protocol_version\x18\x0b \x01(\x05\x12\\\n\x1breal_time_feature_extractor\x18\x0c \x01(\x0b\x32\x35.qwak.feature.store.features.RealTimeFeatureExtractorH\x00\x12Q\n\x16\x64\x61ta_retention_options\x18\r \x01(\x0b\x32\x31.qwak.feature.store.features.DataRetentionOptionsB\x13\n\x11\x66\x65\x61ture_extractor\";\n\x14\x44\x61taRetentionOptions\x12#\n\x1bonline_time_to_live_seconds\x18\x01 \x01(\x03\"\x9d\x01\n\x15\x46\x65\x61tureSetBatchSource\x12<\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.sources.BatchSource\x12\x46\n\x0bread_policy\x18\x02 \x01(\x0b\x32\x31.qwak.feature.store.features.DataSourceReadPolicy\"X\n\x13StreamingFeatureSet\x12\x41\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32+.qwak.feature.store.sources.StreamingSource\"\xc3\x03\n\x15StreamingFeatureSetV1\x12\x41\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32+.qwak.feature.store.sources.StreamingSource\x12\x43\n\x0etransformation\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.Transformation\x12U\n\x0e\x65xecution_spec\x18\x03 \x01(\x0b\x32=.qwak.feature.store.features.execution.StreamingExecutionSpec\x12\x1d\n\x15timestamp_column_name\x18\x04 \x01(\t\x12\x1f\n\x17online_trigger_interval\x18\x05 \x01(\x05\x12!\n\x19offline_scheduling_policy\x18\x06 \x01(\t\x12&\n\x1eqwak_internal_protocol_version\x18\x07 \x01(\x05\x12@\n\x0f\x61uxiliary_sinks\x18\x08 \x03(\x0b\x32\'.qwak.feature.store.sinks.StreamingSink\"\xd7\x04\n\x1eStreamingAggregationFeatureSet\x12\x41\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32+.qwak.feature.store.sources.StreamingSource\x12\x43\n\x0etransformation\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.Transformation\x12U\n\x0e\x65xecution_spec\x18\x03 \x01(\x0b\x32=.qwak.feature.store.features.execution.StreamingExecutionSpec\x12\x1d\n\x15timestamp_column_name\x18\x04 \x01(\t\x12\x1f\n\x17online_trigger_interval\x18\x05 \x01(\x05\x12$\n\x1c\x63ompaction_scheduling_policy\x18\x06 \x01(\t\x12\x46\n\x10\x61ggregation_spec\x18\x07 \x01(\x0b\x32,.qwak.feature.store.features.AggregationSpec\x12\x44\n\rbackfill_spec\x18\x08 \x01(\x0b\x32).qwak.feature.store.features.BackfillSpecB\x02\x18\x01\x12&\n\x1eqwak_internal_protocol_version\x18\t \x01(\x05\x12:\n\x16\x62\x61\x63kfill_max_timestamp\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc3\x01\n\x1b\x42\x61\x63kfillBatchDataSourceSpec\x12<\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.sources.BatchSource\x12\x33\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"|\n\x16\x42\x61\x63kfillDataSourceSpec\x12Z\n\x16\x62\x61tch_data_source_spec\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.features.BackfillBatchDataSourceSpecH\x00\x42\x06\n\x04type\"\xe1\x02\n\x0c\x42\x61\x63kfillSpec\x12T\n\x0e\x65xecution_spec\x18\x01 \x01(\x0b\x32<.qwak.feature.store.features.execution.BackfillExecutionSpec\x12\x33\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x0etransformation\x18\x04 \x01(\x0b\x32+.qwak.feature.store.features.Transformation\x12N\n\x11\x64\x61ta_source_specs\x18\x05 \x03(\x0b\x32\x33.qwak.feature.store.features.BackfillDataSourceSpec\"\x9f\x01\n\x0f\x41ggregationSpec\x12O\n\x0c\x61ggregations\x18\x01 \x03(\x0b\x32\x39.qwak.feature.store.features.aggregation.AggregationField\x12\x15\n\rslide_seconds\x18\x02 \x01(\x05\x12$\n\x1c\x61llowed_late_arrival_seconds\x18\x03 \x01(\x05\"\xdd\x03\n\x0eTransformation\x12L\n\x12udf_transformation\x18\x01 \x01(\x0b\x32..qwak.feature.store.features.UdfTransformationH\x00\x12L\n\x12sql_transformation\x18\x02 \x01(\x0b\x32..qwak.feature.store.features.SqlTransformationH\x00\x12V\n\x15koalas_transformation\x18\x03 \x01(\x0b\x32\x31.qwak.feature.store.features.KoalasTransformationB\x02\x18\x01H\x00\x12T\n\x16pyspark_transformation\x18\x05 \x01(\x0b\x32\x32.qwak.feature.store.features.PySparkTransformationH\x00\x12\x62\n\x1epandas_on_spark_transformation\x18\x06 \x01(\x0b\x32\x38.qwak.feature.store.features.PandasOnSparkTransformationH\x00\x12\x15\n\rartifact_path\x18\x04 \x01(\tB\x06\n\x04type\"*\n\x11UdfTransformation\x12\x15\n\rfunction_name\x18\x01 \x01(\t\"8\n\x11SqlTransformation\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x16\n\x0e\x66unction_names\x18\x02 \x03(\t\"\x83\x01\n\x14KoalasTransformation\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x41\n\x06qwargs\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.TransformArgumentsH\x00:\x02\x18\x01\x42\r\n\x0b\x61rgs_option\"\x80\x01\n\x15PySparkTransformation\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x41\n\x06qwargs\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.TransformArgumentsH\x00\x42\r\n\x0b\x61rgs_option\"\x86\x01\n\x1bPandasOnSparkTransformation\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x41\n\x06qwargs\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.TransformArgumentsH\x00\x42\r\n\x0b\x61rgs_option\"\x90\x01\n\x12TransformArguments\x12K\n\x06qwargs\x18\x01 \x03(\x0b\x32;.qwak.feature.store.features.TransformArguments.QwargsEntry\x1a-\n\x0bQwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x12OnTheFlyFeatureSet\x12:\n\x08\x66unction\x18\x01 \x01(\x0b\x32(.qwak.feature.store.features.UdfFunction\x12\x14\n\x0crequirements\x18\x02 \x01(\x0c\"\x96\x01\n\x08\x46unction\x12@\n\x0csql_function\x18\x01 \x01(\x0b\x32(.qwak.feature.store.features.SqlFunctionH\x00\x12@\n\x0cudf_function\x18\x02 \x01(\x0b\x32(.qwak.feature.store.features.UdfFunctionH\x00\x42\x06\n\x04type\"\xb5\x01\n\x08\x42\x61\x63kfill\x12.\n\nstart_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\rfillup_method\x18\x02 \x01(\x0e\x32\x32.qwak.feature.store.features.Backfill.FillUpMethod\".\n\x0c\x46illUpMethod\x12\x10\n\x0c\x41S_SCHEDULED\x10\x00\x12\x0c\n\x08SNAPSHOT\x10\x01\"\x1a\n\x0bSqlFunction\x12\x0b\n\x03sql\x18\x01 \x01(\t\"\x1b\n\x0bUdfFunction\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x0c\"\t\n\x07NewOnly\"\xa0\x01\n\tTimeFrame\x12\x0f\n\x07minutes\x18\x01 \x01(\x05\x12\x37\n\x07vanilla\x18\x02 \x01(\x0b\x32$.qwak.feature.store.features.VanillaH\x00\x12?\n\x0b\x61ggregation\x18\x03 \x01(\x0b\x32(.qwak.feature.store.features.AggregationH\x00\x42\x08\n\x06\x66lavor\"k\n\x0b\x41ggregation\x12T\n\x16\x61ggregation_population\x18\x01 \x01(\x0b\x32\x32.qwak.feature.store.features.AggregationPopulationH\x00\x42\x06\n\x04type\"\x17\n\x15\x41ggregationPopulation\"\x1c\n\x1aPopulationTimeframeNewOnly\"j\n\x13PopulationTimeframe\x12K\n\x08new_only\x18\x01 \x01(\x0b\x32\x37.qwak.feature.store.features.PopulationTimeframeNewOnlyH\x00\x42\x06\n\x04type\"\t\n\x07Vanilla\"\x9f\x01\n\x08\x46ullRead\x12\x37\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x0b\x32$.qwak.feature.store.features.VanillaH\x00\x12P\n\x14population_timeframe\x18\x02 \x01(\x0b\x32\x30.qwak.feature.store.features.PopulationTimeframeH\x00\x42\x08\n\x06\x66lavor\"\xd2\x01\n\x14\x44\x61taSourceReadPolicy\x12\x38\n\x08new_only\x18\x01 \x01(\x0b\x32$.qwak.feature.store.features.NewOnlyH\x00\x12<\n\ntime_frame\x18\x02 \x01(\x0b\x32&.qwak.feature.store.features.TimeFrameH\x00\x12:\n\tfull_read\x18\x03 \x01(\x0b\x32%.qwak.feature.store.features.FullReadH\x00\x42\x06\n\x04type*}\n\x12\x46\x65\x61tureSetTypeView\x12!\n\x1d\x46\x45\x41TURE_SET_TYPE_VIEW_INVALID\x10\x00\x12\x1f\n\x1b\x46\x45\x41TURE_SET_TYPE_VIEW_BATCH\x10\x01\x12#\n\x1f\x46\x45\x41TURE_SET_TYPE_VIEW_STREAMING\x10\x02\x42[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.feature_set_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _BATCHFEATURESET.fields_by_name['data_sources']._options = None
  _BATCHFEATURESET.fields_by_name['data_sources']._serialized_options = b'\030\001'
  _BATCHFEATURESETV1.fields_by_name['function']._options = None
  _BATCHFEATURESETV1.fields_by_name['function']._serialized_options = b'\030\001'
  _STREAMINGAGGREGATIONFEATURESET.fields_by_name['backfill_spec']._options = None
  _STREAMINGAGGREGATIONFEATURESET.fields_by_name['backfill_spec']._serialized_options = b'\030\001'
  _TRANSFORMATION.fields_by_name['koalas_transformation']._options = None
  _TRANSFORMATION.fields_by_name['koalas_transformation']._serialized_options = b'\030\001'
  _KOALASTRANSFORMATION._options = None
  _KOALASTRANSFORMATION._serialized_options = b'\030\001'
  _TRANSFORMARGUMENTS_QWARGSENTRY._options = None
  _TRANSFORMARGUMENTS_QWARGSENTRY._serialized_options = b'8\001'
  _globals['_FEATURESETTYPEVIEW']._serialized_start=6885
  _globals['_FEATURESETTYPEVIEW']._serialized_end=7010
  _globals['_FEATURESETTYPE']._serialized_start=440
  _globals['_FEATURESETTYPE']._serialized_end=983
  _globals['_BATCHFEATURESET']._serialized_start=986
  _globals['_BATCHFEATURESET']._serialized_end=1399
  _globals['_BATCHFEATURESETV1']._serialized_start=1402
  _globals['_BATCHFEATURESETV1']._serialized_end=2213
  _globals['_DATARETENTIONOPTIONS']._serialized_start=2215
  _globals['_DATARETENTIONOPTIONS']._serialized_end=2274
  _globals['_FEATURESETBATCHSOURCE']._serialized_start=2277
  _globals['_FEATURESETBATCHSOURCE']._serialized_end=2434
  _globals['_STREAMINGFEATURESET']._serialized_start=2436
  _globals['_STREAMINGFEATURESET']._serialized_end=2524
  _globals['_STREAMINGFEATURESETV1']._serialized_start=2527
  _globals['_STREAMINGFEATURESETV1']._serialized_end=2978
  _globals['_STREAMINGAGGREGATIONFEATURESET']._serialized_start=2981
  _globals['_STREAMINGAGGREGATIONFEATURESET']._serialized_end=3580
  _globals['_BACKFILLBATCHDATASOURCESPEC']._serialized_start=3583
  _globals['_BACKFILLBATCHDATASOURCESPEC']._serialized_end=3778
  _globals['_BACKFILLDATASOURCESPEC']._serialized_start=3780
  _globals['_BACKFILLDATASOURCESPEC']._serialized_end=3904
  _globals['_BACKFILLSPEC']._serialized_start=3907
  _globals['_BACKFILLSPEC']._serialized_end=4260
  _globals['_AGGREGATIONSPEC']._serialized_start=4263
  _globals['_AGGREGATIONSPEC']._serialized_end=4422
  _globals['_TRANSFORMATION']._serialized_start=4425
  _globals['_TRANSFORMATION']._serialized_end=4902
  _globals['_UDFTRANSFORMATION']._serialized_start=4904
  _globals['_UDFTRANSFORMATION']._serialized_end=4946
  _globals['_SQLTRANSFORMATION']._serialized_start=4948
  _globals['_SQLTRANSFORMATION']._serialized_end=5004
  _globals['_KOALASTRANSFORMATION']._serialized_start=5007
  _globals['_KOALASTRANSFORMATION']._serialized_end=5138
  _globals['_PYSPARKTRANSFORMATION']._serialized_start=5141
  _globals['_PYSPARKTRANSFORMATION']._serialized_end=5269
  _globals['_PANDASONSPARKTRANSFORMATION']._serialized_start=5272
  _globals['_PANDASONSPARKTRANSFORMATION']._serialized_end=5406
  _globals['_TRANSFORMARGUMENTS']._serialized_start=5409
  _globals['_TRANSFORMARGUMENTS']._serialized_end=5553
  _globals['_TRANSFORMARGUMENTS_QWARGSENTRY']._serialized_start=5508
  _globals['_TRANSFORMARGUMENTS_QWARGSENTRY']._serialized_end=5553
  _globals['_ONTHEFLYFEATURESET']._serialized_start=5555
  _globals['_ONTHEFLYFEATURESET']._serialized_end=5657
  _globals['_FUNCTION']._serialized_start=5660
  _globals['_FUNCTION']._serialized_end=5810
  _globals['_BACKFILL']._serialized_start=5813
  _globals['_BACKFILL']._serialized_end=5994
  _globals['_BACKFILL_FILLUPMETHOD']._serialized_start=5948
  _globals['_BACKFILL_FILLUPMETHOD']._serialized_end=5994
  _globals['_SQLFUNCTION']._serialized_start=5996
  _globals['_SQLFUNCTION']._serialized_end=6022
  _globals['_UDFFUNCTION']._serialized_start=6024
  _globals['_UDFFUNCTION']._serialized_end=6051
  _globals['_NEWONLY']._serialized_start=6053
  _globals['_NEWONLY']._serialized_end=6062
  _globals['_TIMEFRAME']._serialized_start=6065
  _globals['_TIMEFRAME']._serialized_end=6225
  _globals['_AGGREGATION']._serialized_start=6227
  _globals['_AGGREGATION']._serialized_end=6334
  _globals['_AGGREGATIONPOPULATION']._serialized_start=6336
  _globals['_AGGREGATIONPOPULATION']._serialized_end=6359
  _globals['_POPULATIONTIMEFRAMENEWONLY']._serialized_start=6361
  _globals['_POPULATIONTIMEFRAMENEWONLY']._serialized_end=6389
  _globals['_POPULATIONTIMEFRAME']._serialized_start=6391
  _globals['_POPULATIONTIMEFRAME']._serialized_end=6497
  _globals['_VANILLA']._serialized_start=6499
  _globals['_VANILLA']._serialized_end=6508
  _globals['_FULLREAD']._serialized_start=6511
  _globals['_FULLREAD']._serialized_end=6670
  _globals['_DATASOURCEREADPOLICY']._serialized_start=6673
  _globals['_DATASOURCEREADPOLICY']._serialized_end=6883
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import Optional

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    BatchSource as ProtoBatchSource,
    VerticaSource as ProtoVerticaSource,
)
from _qwak_proto.qwak.feature_store.sources.data_source_pb2 import (
    DataSourceSpec as ProtoDataSourceSpec,
)
from qwak.feature_store.data_sources.batch._batch import BaseBatchSource


@dataclass
class VerticaSource(BaseBatchSource):
    host: str
    port: int
    database: str
    schema: str
    table: str
    username_secret_name: str
    password_secret_name: str
    repository: Optional[str] = None

    @classmethod
    def _from_proto(cls, proto):
        vertica = proto.verticaSource
        return cls(
            name=proto.name,
            date_created_column=proto.date_created_column,
            description=proto.description,
            host=vertica.host,
            username_secret_name=vertica.username_secret_name,
            password_secret_name=vertica.password_secret_name,
            database=vertica.database,
            schema=vertica.schema,
            port=vertica.port,
            table=vertica.table,
        )

    def _to_proto(self, artifact_url: Optional[str] = None):
        return ProtoDataSourceSpec(
            data_source_repository_name=self.repository,
            batch_source=ProtoBatchSource(
                name=self.name,
                description=self.description,
                date_created_column=self.date_created_column,
                verticaSource=ProtoVerticaSource(
                    host=self.host,
                    username_secret_name=self.username_secret_name,
                    password_secret_name=self.password_secret_name,
                    database=self.database,
                    schema=self.schema,
                    port=self.port,
                    table=self.table,
                ),
            ),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/v0/azure_credentials.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.ecosystem.v0 import auth_pb2 as qwak_dot_ecosystem_dot_v0_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/ecosystem/v0/azure_credentials.proto\x12\x11qwak.ecosystem.v0\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cqwak/ecosystem/v0/auth.proto\"\xb9\x02\n\x19\x41zureTemporaryCredentials\x12w\n.azure_databricks_service_temporary_credentials\x18\x01 \x01(\x0b\x32=.qwak.ecosystem.v0.AzureDatabricksServiceTemporaryCredentialsH\x00\x12J\n\x16\x64\x61tabricks_credentials\x18\x02 \x01(\x0b\x32(.qwak.ecosystem.v0.DatabricksCredentialsH\x00\x12O\n\x19\x61zure_storage_credentials\x18\x03 \x01(\x0b\x32*.qwak.ecosystem.v0.AzureStorageCredentialsH\x00\x42\x06\n\x04type\"\xc5\x01\n*AzureDatabricksServiceTemporaryCredentials\x12H\n\x16\x64\x61tabricks_credentials\x18\x01 \x01(\x0b\x32(.qwak.ecosystem.v0.DatabricksCredentials\x12M\n\x19\x61zure_storage_credentials\x18\x02 \x01(\x0b\x32*.qwak.ecosystem.v0.AzureStorageCredentials\"j\n\x15\x44\x61tabricksCredentials\x12I\n\x16oauth_token_credential\x18\x01 \x01(\x0b\x32\'.qwak.ecosystem.v0.OAuthTokenCredentialH\x00\x42\x06\n\x04type\"i\n\x17\x41zureStorageCredentials\x12\x46\n\x14sas_token_credential\x18\x01 \x01(\x0b\x32&.qwak.ecosystem.v0.SASTokenCredentialsH\x00\x42\x06\n\x04type\"T\n\x13SASTokenCredentials\x12\r\n\x05token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xb7\x01\n\x1c\x63om.qwak.ai.common.ecosystemP\x01Z\x94\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.v0.azure_credentials_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.qwak.ai.common.ecosystemP\001Z\224\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0'
  _globals['_AZURETEMPORARYCREDENTIALS']._serialized_start=128
  _globals['_AZURETEMPORARYCREDENTIALS']._serialized_end=441
  _globals['_AZUREDATABRICKSSERVICETEMPORARYCREDENTIALS']._serialized_start=444
  _globals['_AZUREDATABRICKSSERVICETEMPORARYCREDENTIALS']._serialized_end=641
  _globals['_DATABRICKSCREDENTIALS']._serialized_start=643
  _globals['_DATABRICKSCREDENTIALS']._serialized_end=749
  _globals['_AZURESTORAGECREDENTIALS']._serialized_start=751
  _globals['_AZURESTORAGECREDENTIALS']._serialized_end=856
  _globals['_SASTOKENCREDENTIALS']._serialized_start=858
  _globals['_SASTOKENCREDENTIALS']._serialized_end=942
# @@protoc_insertion_point(module_scope)



#
#    Copyright 2024 OpenAI
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

from dataclasses import dataclass
from typing import List, Optional

from qwak.llmops.generation.base import ModelResponse
from .chat_completion_message import ChatCompletionMessage
from .chat_completion_token_logprob import ChatCompletionTokenLogprob
from ..completion_usage import CompletionUsage

__all__ = ["ChatCompletion", "Choice", "ChoiceLogprobs"]


@dataclass
class ChoiceLogprobs:
    content: Optional[List[ChatCompletionTokenLogprob]] = None
    """A list of message content tokens with log probability information."""


@dataclass
class Choice:
    finish_reason: str
    """The reason the model stopped generating tokens.

    This will be `stop` if the model hit a natural stop point or a provided stop
    sequence, `length` if the maximum number of tokens specified in the request was
    reached, `content_filter` if content was omitted due to a flag from our content
    filters, `tool_calls` if the model called a tool, or `function_call`
    (deprecated) if the model called a function.
    """

    index: int
    """The index of the choice in the list of choices."""

    message: ChatCompletionMessage
    """A chat completion message generated by the model."""

    logprobs: Optional[ChoiceLogprobs] = None
    """Log probability information for the choice."""

    def __post_init__(self):
        """Validates that finish_reason is one of the allowed values."""
        allowed_reasons = {
            "stop",
            "length",
            "tool_calls",
            "content_filter",
            "function_call",
        }
        if self.finish_reason not in allowed_reasons:
            raise ValueError(
                f"Invalid finish_reason: '{self.finish_reason}'. "
                f"Must be one of {allowed_reasons}"
            )


@dataclass
class ChatCompletion(ModelResponse):
    id: str
    """A unique identifier for the chat completion."""

    choices: List[Choice]
    """A list of chat completion choices.

    Can be more than one if `n` is greater than 1.
    """

    created: int
    """The Unix timestamp (in seconds) of when the chat completion was created."""

    model: str
    """The model used for the chat completion."""

    object: str
    """The object type, which is always `chat.completion`."""

    system_fingerprint: Optional[str] = None
    """This fingerprint represents the backend configuration that the model runs with.

    Can be used in conjunction with the `seed` request parameter to understand when
    backend changes have been made that might impact determinism.
    """

    usage: Optional[CompletionUsage] = None
    """Usage statistics for the completion request."""

    def __post_init__(self):
        """Validates that the object type is correct."""
        if self.object != "chat.completion":
            raise ValueError(
                f"Invalid object type: '{self.object}'. Must be 'chat.completion'"
            )



import importlib

from qwak.inner.build_logic.interface.step_inteface import Step
from qwak import __version__ as qwak_core_version


class SetVersionStep(Step):
    STEP_DESCRIPTION = "Getting SDK Version"
    SDK_VERSION_NOT_AVAILABLE_MSG_FORMAT = (
        "Sdk version not available, using core version {qwak_core_version}"
    )
    SDK_VERSION_FOUND_MSG_FORMAT = "Found sdk version {qwak_sdk_version}"

    def description(self) -> str:
        return self.STEP_DESCRIPTION

    def execute(self) -> None:
        try:
            self.build_logger.debug("Getting sdk version")
            qwak_sdk_version = importlib.import_module("qwak_sdk").__version__
            self.context.qwak_sdk_version = qwak_sdk_version
            self.build_logger.debug(
                self.SDK_VERSION_FOUND_MSG_FORMAT.format(
                    qwak_sdk_version=qwak_sdk_version
                )
            )
        except ImportError:
            self.build_logger.debug(
                self.SDK_VERSION_NOT_AVAILABLE_MSG_FORMAT.format(
                    qwak_core_version=qwak_core_version
                )
            )
            self.context.qwak_sdk_version = qwak_core_version



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/fitness_service/status.proto\x12\x14qwak.fitness.service\"\xa2\x01\n\tPodStatus\x12\x41\n\x12\x63ontainer_statuses\x18\x01 \x03(\x0b\x32%.qwak.fitness.service.ContainerStatus\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x12\n\nstart_time\x18\x05 \x01(\t\x12\x0e\n\x06pod_id\x18\x06 \x01(\t\"\x9d\x01\n\x0f\x43ontainerStatus\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x15\n\rrestart_count\x18\x03 \x01(\x05\x12\x0f\n\x07started\x18\x04 \x01(\x08\x12=\n\x0f\x63ontainer_state\x18\x05 \x01(\x0b\x32$.qwak.fitness.service.ContainerState\"\x8f\x02\n\x0e\x43ontainerState\x12N\n\x17\x63ontainer_state_running\x18\x01 \x01(\x0b\x32+.qwak.fitness.service.ContainerStateRunningH\x00\x12T\n\x1a\x63ontainer_state_terminated\x18\x02 \x01(\x0b\x32..qwak.fitness.service.ContainerStateTerminatedH\x00\x12N\n\x17\x63ontainer_state_waiting\x18\x03 \x01(\x0b\x32+.qwak.fitness.service.ContainerStateWaitingH\x00\x42\x07\n\x05state\"+\n\x15\x43ontainerStateRunning\x12\x12\n\nstarted_at\x18\x01 \x01(\t\"\x9d\x01\n\x18\x43ontainerStateTerminated\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x11\n\texit_code\x18\x02 \x01(\x05\x12\x13\n\x0b\x66inished_at\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0e\n\x06signal\x18\x06 \x01(\x05\x12\x12\n\nstarted_at\x18\x07 \x01(\t\"8\n\x15\x43ontainerStateWaiting\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\tB#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.fitness_service.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _globals['_PODSTATUS']._serialized_start=60
  _globals['_PODSTATUS']._serialized_end=222
  _globals['_CONTAINERSTATUS']._serialized_start=225
  _globals['_CONTAINERSTATUS']._serialized_end=382
  _globals['_CONTAINERSTATE']._serialized_start=385
  _globals['_CONTAINERSTATE']._serialized_end=656
  _globals['_CONTAINERSTATERUNNING']._serialized_start=658
  _globals['_CONTAINERSTATERUNNING']._serialized_end=701
  _globals['_CONTAINERSTATETERMINATED']._serialized_start=704
  _globals['_CONTAINERSTATETERMINATED']._serialized_end=861
  _globals['_CONTAINERSTATEWAITING']._serialized_start=863
  _globals['_CONTAINERSTATEWAITING']._serialized_end=919
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURE_NAMES_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """The name of the featureset"""
    @property
    def feature_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The name of the features"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        feature_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_names", b"feature_names", "featureset_name", b"featureset_name"]) -> None: ...

global___FeaturesetFeatures = FeaturesetFeatures
